@@ -1,4 +1,4 @@
-/* $Id: gps.h 4060 2006-12-02 16:44:26Z esr $ */
+/* $Id: gps.h 4509 2007-12-11 00:44:16Z esr $ */
 /* gps.h -- interface of the libgps library */
 
 #ifndef gps_h
@@ -11,13 +11,7 @@ extern "C" {
 #include <sys/types.h>
 #include <sys/time.h>
 #include <stdbool.h>
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#else
-#ifdef HAVE_INTTYPES_H
-#include <inttypes.h>
-#endif
-#endif
+#include <inttypes.h>	/* stdint.h would be smaller but not all have it */ 
 #include <limits.h>
 #include <time.h>
 #include <signal.h>
@@ -295,9 +289,6 @@ struct gps_data_t {
 
     /* these members are private */
     int gps_fd;			/* socket or file descriptor to GPS */
-#ifdef NMEADISC
-    int ldisc;			/* current line discipline */
-#endif
     void (*raw_hook)(struct gps_data_t *, char *, size_t len, int level);/* Raw-mode hook for GPS data. */
     void (*thread_hook)(struct gps_data_t *, char *, size_t len, int level);/* Thread-callback hook for GPS data. */
 };
@@ -325,7 +316,7 @@ extern char *gps_show_transfer(int);
 extern time_t mkgmtime(register struct tm *);
 extern double timestamp(void);
 extern double iso8601_to_unix(char *);
-extern /*@observer@*/char *unix_to_iso8601(double t, /*@ out @*/char[], int len);
+extern /*@observer@*/char *unix_to_iso8601(double t, /*@ out @*/char[], size_t len);
 extern double gpstime_to_unix(int, double);
 extern void unix_to_gpstime(double, /*@out@*/int *, /*@out@*/double *);
 extern double earth_distance(double, double, double, double);
